{*****************************************************************************
 *
 *  TestGeo.pas - Main form
 *
 *  Copyright (c) 1999 Diego Amicabile
 *
 *  Author:     Diego Amicabile
 *  E-mail:     diegoami@yahoo.it
 *  Homepage:   http://www.geocities.com/diegoami
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation;
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *----------------------------------------------------------------------------
 *
 *  Revision history:
 *
 *     DATE     REV                 DESCRIPTION
 *  ----------- --- ----------------------------------------------------------
 *
 *****************************************************************************}

unit TestGeo;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, ComCtrls, CustomHImages, HImages, StdCtrls,GeoGlobal,
  UQuesiti,MPlayer, Menus, Spin, inifiles,
  shellapi;

type
  TMainForm = class(TForm)
    PageControl: TPageControl;
    Nation: TTabSheet;
    NationHyperImages: THyperImages;
    FindTownsLabel: TLabel;
    NomeCittaLabel: TLabel;
    TownToFindLabel: TLabel;
    Timer: TTimer;
    MediaPlayer: TMediaPlayer;
    AuthorLabel: TLabel;
    Questions: TTabSheet;
    TimeTrackBar: TTrackBar;
    SoundCheckBox: TCheckBox;
    SpinEdit: TSpinEdit;
    TownsTrackBar: TTrackBar;
    TimeLabel: TLabel;
    QuestionLabel: TLabel;
    BonusLabel: TLabel;
    ListBox: TListBox;
    StartButton: TButton;
    SaveButton: TButton;
    HelpButton: TButton;
    TownsDontLikeLabel: TLabel;
    ProgressBar: TProgressBar;
    RadioGroup: TRadioGroup;
    Regions: TTabSheet;
    RegionsHyperImages: THyperImages;
    ThatTownIsLabel: TLabel;
    HotSpotLabel: TLabel;
    ColorDialog: TColorDialog;
    ColorButton: TButton;
    procedure NationHyperImagesImageMouseDown(Sender: TObject;
      Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
    procedure FormCreate(Sender: TObject);
    procedure NewTown;
    procedure FormActivate(Sender: TObject);
    procedure ShowRegion(ChosenRegion : TRegion);
    procedure RegionsHyperImagesImageMouseDown(Sender: TObject;
      Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
    procedure PageControlChange(Sender: TObject);
    procedure RadioGroupClick(Sender: TObject);
    procedure TimerTimer(Sender: TObject);
    procedure PlaySound(Wave : String);
    procedure SoundClick(Sender: TObject);
    procedure TimeTrackBarChange(Sender: TObject);
    procedure TimerClick(Sender: TObject);
    procedure FillList(Hyper : THyperImages; ListBox : TListBox);
    procedure StartButtonClick(Sender: TObject);
    procedure SaveButtonClick(Sender: TObject);
    procedure HelpButtonClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure ColorButtonClick(Sender: TObject);
  private
    MCIopen       : boolean;
    procedure TrySound;
  public
    Controller : TForm;
  end;
var
  MainForm: TMainForm;

implementation

{$R *.DFM}


procedure TMainForm.ShowRegion(ChosenRegion : TRegion);
begin
     RegionsHyperImages.LoadImageFromFile(RegionFile[ChosenRegion]);
     PageControl.SelectNextPage(true);

end;

procedure TMainForm.NationHyperImagesImageMouseDown(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
var
  S: String;
begin
  with NationHyperImages do
    if PointIsOnTarget(X, Y, S) then begin
      CurrentRegion := StringToRegion(S);
      ShowRegion(CurrentRegion);
    end;
end;


procedure TMainForm.NewTown;
begin
  TownToFind := Session.GetNextTown;
  TownToFindLabel.Caption :=  TownToFind;
  if TownToFind = '' then begin
    PlaySound('Applaude.wav');
    Timer.Enabled := False;
    MessageDlg('Very good! You have found them all!',mtInformation,[mbOk], 0);
      Session.Free;
  end;
end;

procedure TMainForm.TrySound;
begin
  with MediaPlayer do begin
    FileName := 'Whistle.wav';
    Open;
    if Error = 0 then MCIopen := True
      else MCIopen := false;
  end;
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  Randomize;
  NationHyperImages.PicturesDir := GetCurrentDir+'\images';
  RegionsHyperImages.PicturesDir := GetCurrentDir+'\images';
  FillList(RegionsHyperImages,ListBox);
  SpinEdit.Value := NQUESTIONS;
  ScaleBy(round(sqrt(Screen.Width*Screen.Height)),round(sqrt(800*600)));
  with MediaPlayer do begin
    FileName := 'Whistle.wav';
    Open;
    if Error = 0 then MCIopen := True;
  end;
end;

procedure TMainForm.FormActivate(Sender: TObject);
begin
  if Guessed = True then begin
    NewTown;
    HotSpotLabel.Caption := '';
    Guessed := False;
  end;
end;

procedure TMainForm.RegionsHyperImagesImageMouseDown(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
var
  S: String;
begin
  with RegionsHyperImages do
    if PointIsOnTarget(X, Y, S) then begin
      HotSpotLabel.Caption := S;
      if S = TownToFindLabel.Caption then begin
        Guessed := true;
        PlaySound('Whistle.wav');
        MessageDlg('Good! ',mtInformation,[mbOk], 0);
        Session.DisableTown;
        ProgressBar.Position := ProgressBar.Position+TownsTrackBar.Position div 2;
        PageControl.ActivePage := Nation;
        PageControlChange(self);
      end else if S <> '' then begin
        PlaySound('Cough2.wav');
        ProgressBar.Position := ProgressBar.Position-TownsTrackBar.Position;
      end;
    end;
end;

procedure TMainForm.PageControlChange(Sender: TObject);
begin
  if Guessed = True then begin
    HotSpotLabel.Caption := '';
    NewTown;
    Guessed := False;
  end;
end;

procedure TMainForm.RadioGroupClick(Sender: TObject);
begin
  TownToFindLabel.Caption :=   RadioGroup.Items[RadioGroup.ItemIndex];
  Guessed := False;
end;

procedure TMainForm.TimerTimer(Sender: TObject);
begin
  ProgressBar.Position := ProgressBar.Position - 1;
  if ProgressBar.Position = 0 then begin
    PlaySound('Moan.wav');
    Timer.Enabled := False;
    MessageDlg('Time Up!',mtError,[mbOk], 0);
  end else if (MCIopen) and (MediaPlayer.Position >= MediaPlayer.Length) then
      PlaySound('Movehit1.wav');
end;

procedure TMainForm.PlaySound(Wave : String);
begin
  if (SoundCheckBox.Checked) and MCIopen then
    with MediaPlayer do begin
      FileName := Wave;
      Open;
      Play;
    end;
end;

procedure TMainForm.SoundClick(Sender: TObject);
begin
  TrySound;
end;

procedure TMainForm.TimeTrackBarChange(Sender: TObject);
begin
  Timer.Interval := TimeTrackbar.Position;
end;

procedure TMainForm.TimerClick(Sender: TObject);
begin
  TimeTrackBar.SetFocus;
end;

procedure TMainForm.FillList(Hyper : THyperImages; ListBox : TListBox);
var Enum, Index : integer;
begin
  Index := 0;
  ListBox.Items.Clear;
  for Enum := 0 to Hyper.HotSpotsDef.Count-1 do
    if ListBox.Items.IndexOf(HSDToTown(Hyper.HotSpotsDef.Strings[Enum])) = -1 then begin
      ListBox.Items.Insert(Index,HSDToTown(Hyper.HotSpotsDef.Strings[Enum]));
      Inc(Index);
    end;
end;

procedure TMainForm.StartButtonClick(Sender: TObject);
begin
  Timer.Enabled := True;
  NQUESTIONS := SpinEdit.Value;
  RadioGroup.Items.Clear;
  Progressbar.Position := Progressbar.Max;
  Timer.Interval := TimeTrackbar.Position;
  Session := TSession.Init(RadioGroup,RegionsHyperImages, ListBox);
  TownToFindLabel.Caption :=  RadioGroup.Items[RadioGroup.ItemIndex];
  PageControl.ActivePage := Nation;
end;




procedure TMainForm.SaveButtonClick(Sender: TObject);
var 
    i : integer;
begin
  for i := 0 to ListBox.Items.Count-1 do
    IlFileIni.WriteBool(User,ListBox.Items.Strings[i],ListBox.Selected[i]);
  IlFileIni.WriteInteger(User,'Time',TimeTrackBar.Position);
  IlFileIni.WriteInteger(User,'Bonus',TownsTrackBar.Position);
  IlFileIni.WriteInteger(User,'Numquesiti',SpinEdit.Value);
  IlFileIni.WriteBool(User,'Sound',SoundCheckBox.Checked);
end;

procedure TMainForm.HelpButtonClick(Sender: TObject);
var HelpFile : String;
begin
  HelpFile := GetCurrentDir+'\images\help.html';
  Shellexecute(0,nil,Pchar(HelpFile),nil,nil,SW_NORMAL);
end;

procedure TMainForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  Controller.Close;
  Application.Terminate;
end;

procedure TMainForm.ColorButtonClick(Sender: TObject);
begin
  if ColorDialog.Execute then
    MainForm.Color := ColorDialog.Color;
end;

end.


